import os

from egse.metrics import get_metrics_repo


def test_get_metrics_repo():
    token = os.environ.get("INFLUXDB3_AUTH_TOKEN")

    influxdb = get_metrics_repo("influxdb", {"host": "http://localhost:8181", "database": "ARIEL", "token": token})
    influxdb.connect()

    result = influxdb.query("SELECT * FROM cm ORDER BY TIME DESC LIMIT 20", mode="pandas")
    print(result)

    # result = influxdb.query("SHOW TABLES;")
    # result = influxdb.query("SHOW COLUMNS IN cm;", mode="pandas")
    # print(f"Columns in cm: {result}")

    result = influxdb.get_table_names()
    print(f"Tables in ARIEL: {result}")

    result = influxdb.get_column_names("cm")
    print(f"Columns in cm: {result}")

    influxdb.close()



from egse.setup import Setup
from egse.state import GlobalState


def test_state():
    assert GlobalState.setup is None

    # The following test depends on whether the configuration manager is running or not
    assert isinstance(GlobalState.load_setup(), (Setup, None))



import logging

from egse.plugin import load_plugins_fn

logger = logging.getLogger("test")


def test_load_plugins_fn():
    # Load ALL plugins from the `egse.plugins` namespace
    plugins_1 = load_plugins_fn("plugins/**/*.py", "egse")
    print(plugins_1)

    # Load ALL plugins from the `egse.plugins` namespace
    plugins_2 = load_plugins_fn("**/*.py", "egse.plugins")
    print(plugins_2)

    assert plugins_1.keys() == plugins_2.keys()

    assert "influxdb" in plugins_1
    assert "fits" in plugins_1
    assert "hdf5" in plugins_1

    # No Exception should be raised when the module doesn't exist
    plugins = load_plugins_fn("not-a-module")
    assert plugins == {}

    # Load a normal regular module
    plugins = load_plugins_fn("bits.py", "egse")
    assert "bits" in plugins



__all__ = [
    "DEFAULT_NH_COLLECTION_PORT",
    "DEFAULT_NH_PUBLISH_PORT",
]

# Default ports that are assigned to PUSH-PULL and PUB-SUB protocols of the notification hub.
DEFAULT_NH_COLLECTION_PORT = 4245
DEFAULT_NH_PUBLISH_PORT = 4246
